import request from '@/utils/request'

// 查询护工信息列表
export function nursingWorkerPage (query) {
  return request({
    url: '/info/nursingWorker/page',
    method: 'get',
    params: query
  })
}
// 新增护工信息
export function nursingWorkerAdd (data) {
  return request({
    url: '/info/nursingWorker/add',
    method: 'post',
    data
  })
}
// 获取护工信息详细信息
export function nursingWorkerInfo (id) {
  return request({
    url: `/info/nursingWorker/info/${id}`,
    method: 'get',
  })
}
// 修改护工信息
export function nursingWorkerEdit (data) {
  return request({
    url: '/info/nursingWorker/edit',
    method: 'post',
    data
  })
}
// 删除护工信息
export function nursingWorkerDel (ids) {
  return request({
    url: `/info/nursingWorker/del/${ids}`,
    method: 'post',
  })
}
// 禁用启用护工
export function nursingWorkerUpdateStatus (data) {
  return request({
    url: `/info/nursingWorker/update-status`,
    method: 'post',
    data
  })
}